package bin;

import kernel.service.ServiceManager;
import lib.CLIAppBase;

using tink.CoreApi;

class Service extends CLIAppBase {
    public function new() {
        registerSyncSubcommand("start", (args) ->{
            if (args.length < 1) {
                return false;
            }

            var name = args[0];

            var result = ServiceManager.instance.start(name);
            return handleResult(result);
        },"Start a service");

        registerSyncSubcommand("stop", (args) ->{
            if (args.length < 1) {
                return false;
            }

            var name = args[0];

            var result = ServiceManager.instance.stop(name);
            return handleResult(result);
        },"Stop a service");

        registerSyncSubcommand("register", (args) ->{
            if (args.length < 2) {
                return false;
            }

            var name = args[0];
            var binName = args[1];
            var rest = args.slice(2);

            var result = ServiceManager.instance.register(name, binName, rest);
            return handleResult(result);
        },"Register a new service");

        registerSyncSubcommand("unregister", (args) ->{
            if (args.length < 2) {
                return false;
            }

            var name = args[0];

            var result = ServiceManager.instance.unregister(name);
            return handleResult(result);
        },"Unregister a service");

        registerSyncSubcommand("list", (args) ->{
            
            var list = ServiceManager.instance.listRunning();
            
            for (name in list) {
                this.handle.writeLine(name);
            }

            return true;
        },"List all services");

        registerSyncSubcommand("enable", (args) ->{
            if (args.length < 1) {
                return false;
            }

            ServiceManager.instance.enable(args[0]);
            return true;
        },"Enable a service");
    }

    private function handleResult(res: Outcome<Noise,String>): Bool {
        switch (res) {
            case Success(_):
                return true;
            case Failure(e):
                this.handle.write(e);
                return false;
        }
    }
}